==> kazehakase-0.5.5.tar.gz: kazehakase-0.5.5/src/bookmarks/kz-bookmarks-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "kz-bookmarks-enum-types.h"
#include "kz-bookmark.h"
#include "kz-history.h"
#include "kz-xbel.h"
#include "kz-rss.h"
#include "kz-nsbookmark.h"
#include "kz-lirs.h"
#include "kz-hinadi.h"
#include "kz-proxy-folder.h"
#include "kz-root-bookmark.h"
#include "kz-smart-bookmark.h"
#include "kz-bookmark-file.h"
#include "kz-bookmark-filter.h"
#include "kz-bookmark-bar.h"
#include "kz-bookmark-item.h"
#include "kz-bookmark-menu.h"
#include "kz-bookmark-menu-item.h"
#include "kz-bookmark-base-menu-item.h"
#include "kz-bookmark-separator-menu-item.h"
#include "kz-bookmark-folder-menu-item.h"
#include "kz-bookmark-menu-item-list.h"
#include "kz-bookmark-tab-menu.h"
#include "kz-bookmarks-view.h"
#include "kz-bookmark-edit.h"
#include "kz-bookmark-editor.h"
#include "kz-bookmark-edit-win.h"
#include "kz-bookmark-utils.h"
#include "kz-actions-bookmark.h"
#include "kz-session.h"
#include "kz-w3mbookmark.h"

/* enumerations from "kz-bookmark.h" */
GType
kz_bookmark_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_BOOKMARK_NORMAL, "KZ_BOOKMARK_NORMAL", "normal" },
      { KZ_BOOKMARK_FOLDER, "KZ_BOOKMARK_FOLDER", "folder" },
      { KZ_BOOKMARK_PURE_FOLDER, "KZ_BOOKMARK_PURE_FOLDER", "pure-folder" },
      { KZ_BOOKMARK_SEPARATOR, "KZ_BOOKMARK_SEPARATOR", "separator" },
      { KZ_BOOKMARK_N_TYPES, "KZ_BOOKMARK_N_TYPES", "n-types" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzBookmarkType", values);
  }
  return etype;
}
GType
kz_bookmark_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_BOOKMARK_FOLDED_FLAG, "KZ_BOOKMARK_FOLDED_FLAG", "flag" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzBookmarkFlag", values);
  }
  return etype;
}

/* enumerations from "kz-bookmark-file.h" */
GType
kz_bookmark_file_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_BOOKMARK_FILE_EDITABLE_FLAG, "KZ_BOOKMARK_FILE_EDITABLE_FLAG", "flag" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzBookmarkFileFlag", values);
  }
  return etype;
}
GType
kz_bookmark_file_state_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_BOOKMARK_FILE_STATE_NORMAL, "KZ_BOOKMARK_FILE_STATE_NORMAL", "normal" },
      { KZ_BOOKMARK_FILE_STATE_LOADING, "KZ_BOOKMARK_FILE_STATE_LOADING", "loading" },
      { KZ_BOOKMARK_FILE_STATE_SAVING, "KZ_BOOKMARK_FILE_STATE_SAVING", "saving" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzBookmarkFileState", values);
  }
  return etype;
}

/* Generated data ends here */

==> kazehakase_0.5.8.orig.tar.gz: kazehakase-0.5.8/src/bookmarks/kz-bookmarks-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "kz-bookmarks-enum-types.h"
#include "kz-bookmark-objects.h"
#include "kz-bookmark.h"
#include "kz-history.h"
#include "kz-xbel.h"
#include "kz-rss.h"
#include "kz-nsbookmark.h"
#include "kz-lirs.h"
#include "kz-hinadi.h"
#include "kz-proxy-folder.h"
#include "kz-root-bookmark.h"
#include "kz-smart-bookmark.h"
#include "kz-bookmark-file.h"
#include "kz-xmlrpc-bookmark.h"
#include "kz-bookmark-separator.h"
#include "kz-bookmark-filter.h"
#include "kz-bookmark-folder.h"
#include "kz-bookmark-bar.h"
#include "kz-bookmark-item.h"
#include "kz-bookmark-menu.h"
#include "kz-bookmark-menu-item.h"
#include "kz-bookmark-base-menu-item.h"
#include "kz-bookmark-separator-menu-item.h"
#include "kz-bookmark-folder-menu-item.h"
#include "kz-bookmark-menu-item-list.h"
#include "kz-bookmark-tab-menu.h"
#include "kz-bookmarks-view.h"
#include "kz-bookmark-edit.h"
#include "kz-bookmark-editor.h"
#include "kz-bookmark-edit-win.h"
#include "kz-bookmark-utils.h"
#include "kz-actions-bookmark.h"
#include "kz-session.h"
#include "kz-w3mbookmark.h"

/* enumerations from "kz-bookmark-file.h" */
GType
kz_bookmark_file_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_BOOKMARK_FILE_EDITABLE_FLAG, "KZ_BOOKMARK_FILE_EDITABLE_FLAG", "flag" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzBookmarkFileFlag", values);
  }
  return etype;
}
GType
kz_bookmark_file_state_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_BOOKMARK_FILE_STATE_NORMAL, "KZ_BOOKMARK_FILE_STATE_NORMAL", "normal" },
      { KZ_BOOKMARK_FILE_STATE_LOADING, "KZ_BOOKMARK_FILE_STATE_LOADING", "loading" },
      { KZ_BOOKMARK_FILE_STATE_SAVING, "KZ_BOOKMARK_FILE_STATE_SAVING", "saving" },
      { KZ_BOOKMARK_FILE_STATE_DISPOSING, "KZ_BOOKMARK_FILE_STATE_DISPOSING", "disposing" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzBookmarkFileState", values);
  }
  return etype;
}

/* Generated data ends here */
